pub enum KeyResolve<A> {
Pending,
Match(Binding<A>),
Ambiguous,
Unbound(Vec<KeyEvent>),
}Expand description
Result of feeding a key event into the keymap.
Variants
Pending
The key extends an incomplete chord — wait for more keys.
Match(Binding<A>)
A terminal chord was matched.
Ambiguous
An exact terminal match exists and longer chords also start with this prefix. Caller waits for timeout to disambiguate.
Unbound(Vec<KeyEvent>)
No chord matches the buffered sequence. Vec contains the buffered
keys (including the last one) that should be replayed to the engine.